Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(436)

Unified Diff: public/platform/WebServiceWorkerProxy.h

Issue 256723002: Remove the queued states mechanism from ServiceWorker (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: finish removal of stuff Created 6 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « public/platform/WebServiceWorker.h ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: public/platform/WebServiceWorkerProxy.h
diff --git a/public/platform/WebServiceWorkerProxy.h b/public/platform/WebServiceWorkerProxy.h
index 57b0028b7fecfad58cdc2ab8865de2fd559e559a..feb6883a3868ad8551526097985f2e33b010783a 100644
--- a/public/platform/WebServiceWorkerProxy.h
+++ b/public/platform/WebServiceWorkerProxy.h
@@ -11,14 +11,14 @@ namespace blink {
// the embedder, to talk to the ServiceWorker object from embedder.
class WebServiceWorkerProxy {
public:
- // Informs the proxy that the service worker's state changed. The state
- // should be accessible via WebServiceWorker.state() but may not necessarily
- // be immediately reflected. For example, this happens if the proxy is
- // waiting for the registration promise to resolve, while the browser has
- // already registered and activated the worker.
- virtual void onStateChanged(WebServiceWorkerState) = 0;
+ // Returns true if the proxy is ready to be notified of service worker state
+ // changes. It may not be if it's waiting for the registration promise to
+ // resolve, while the browser side has registered and is proceeding to
+ // install and activate the worker.
+ virtual bool isReady() = 0;
- // FIXME: To be removed, this is just here as part of a three-sided patch.
+ // Notifies the proxy that the service worker state changed. The new state
+ // should be accessible via WebServiceWorker.state().
virtual void dispatchStateChangeEvent() = 0;
};
« no previous file with comments | « public/platform/WebServiceWorker.h ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698